
RTB_registerPref("Max Ammo", "Ammo Bow", "$Pref::AmmoBow::MaxAmmo", "int 1 999999", "Weapon_AmmoBow", "16");

package AmmoBowPickup
{
	function Armor::onCollision(%this, %obj, %col, %vec, %speed) 
	{
		if (%obj.getState() $= "Dead")
		{
			return;
		}
		if (%obj.getDamagePercent() >= 1.0)
		{
			return;
		}
		%colClassName = %col.getClassName();
		if (%colClassName $= "Item" && %col.getDatablock().arrowAmmo > 0 && %col.canPickup)
		{

			if (%obj.numArrows >= $Pref::AmmoBow::MaxAmmo)
				return parent::onCollision(%this, %obj, %col, %vec, %speed);

			%canUse = 1;
			if (miniGameCanUse(%obj, %col) == 0)
				%canUse = 0;

			if (!%canUse)
			{
				if (isObject(%col.spawnBrick))
					%ownerName = %col.spawnBrick.getGroup().name;

				if ($lastError == $LastError::Trust)
				{
					%msg = %ownerName @ " does not trust you enough to use this item.";
				}
				else if ($lastError == $LastError::MiniGameDifferent)
				{
					if (isObject(%client.miniGame))
						%msg = "This item is not part of the mini-game.";
					else
						%msg = "This item is part of a mini-game.";
				}
				else if ($lastError == $LastError::MiniGameNotYours)
					%msg = "You do not own this item.";
				else if ($lastError == $LastError::NotInMiniGame)
					%msg = "This item is not part of the mini-game.";

				commandToClient(%obj.client, 'CenterPrint', %msg, 1);
				return;
			}

			if (%canUse)
			{
				%diff = %obj.numArrows + %col.getDatablock().arrowAmmo - $Pref::AmmoBow::MaxAmmo;

				if (%diff > 0)
					return parent::onCollision(%this, %obj, %col, %vec, %speed);
				else
					%obj.numArrows += %col.getDatablock().arrowAmmo;

				if (isObject(%obj.client))
					%obj.client.centerprint("<just:right><color:ffffff>Arrows: \c3" @ %obj.numArrows @ "/" @ $Pref::AmmoBow::MaxAmmo @ " ", 3);

				if (%col.isStatic())
					%col.respawn();
				else
					%col.delete();
			}
		}
		else
		{
			parent::onCollision(%this, %obj, %col, %vec, %speed);
		}
	}
};
activatePackage(AmmoBowPickup);

datablock ItemData(AmmoBowArrowItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./arrowItem.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Ammo - Arrow";
	doColorShift = true;
	colorShiftColor = "0.400 0.196 0 1.000";

	 // Dynamic properties defined by the scripts
	image = AmmoBowArrowImage;
	canDrop = true;

	arrowAmmo = 1;
};

datablock ShapeBaseImageData(AmmoBowArrowImage : hammerImage)
{
	shapeFile = "./arrowItem.dts";

	eyeRotation = "";
	eyeOffset = "";
	offset = "";

	item = AmmoBowArrowItem;
	doColorShift = true;
	colorShiftColor = "0.400 0.196 0 1.000";

	stateName[0]					= "Activate";
	stateTimeoutValue[0]			= 0.1;
	stateTransitionOnTimeout[0]		= "Ready";

	stateName[1]					= "Ready";
	stateTransitionOnTriggerDown[1]	= "Use";
	stateTimeoutValue[1]			= 0;
	stateTransitionOnTriggerUp[1]	= "";

	stateName[2]					= "Use";
	stateTimeoutValue[2]			= 0.2;
	stateScript[2]					= "onUse";
	stateTransitionOnTimeout[2] 	= "Ready";
	stateTransitionOnTriggerUp[1]	= "";
};

function AmmoBowArrowImage::onUse(%this, %obj, %slot)
{
	if (%obj.numArrows >= $Pref::AmmoBow::MaxAmmo)
	{
		if (isObject(%obj.client))
			%obj.client.centerprint("You already have full ammo!", 2);
		return;
	}
	
	%obj.numArrows += %this.item.arrowAmmo;
	%obj.numArrows = getMin(%obj.numArrows, $Pref::AmmoBow::MaxAmmo);

	%obj.tool[%obj.currTool] = 0;
	%obj.weaponCount--;
	messageClient(%obj.client, 'MsgItemPickup', '', %obj.currTool, 0);
	%obj.client.centerprint("<just:right><color:ffffff>Arrows: \c3" @ %obj.numArrows @ "/" @ $Pref::AmmoBow::MaxAmmo @ " ", 3);
	%obj.unmountImage(%slot);
}


datablock ItemData(AmmoBowQuiverItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./quiverItem.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Ammo - Quiver";
	doColorShift = true;
	colorShiftColor = "0.400 0.196 0 1.000";

	 // Dynamic properties defined by the scripts
	image = AmmoBowQuiverImage;
	canDrop = true;

	arrowAmmo = 5;
};

datablock ShapeBaseImageData(AmmoBowQuiverImage : hammerImage)
{
	shapeFile = "./quiverItem.dts";

	eyeRotation = "";
	eyeOffset = "";
	offset = "";

	item = AmmoBowQuiverItem;
	doColorShift = true;
	colorShiftColor = "0.400 0.196 0 1.000";

	stateName[0]					= "Activate";
	stateTimeoutValue[0]			= 0.1;
	stateTransitionOnTimeout[0]		= "Ready";

	stateName[1]					= "Ready";
	stateTransitionOnTriggerDown[1]	= "Use";
	stateTimeoutValue[1]			= 0;
	stateTransitionOnTriggerUp[1]	= "";

	stateName[2]					= "Use";
	stateTimeoutValue[2]			= 0.2;
	stateScript[2]					= "onUse";
	stateTransitionOnTimeout[2] 	= "Ready";
	stateTransitionOnTriggerUp[1]	= "";
};

function AmmoBowQuiverImage::onUse(%this, %obj, %slot)
{
	if (%obj.numArrows >= $Pref::AmmoBow::MaxAmmo)
	{
		if (isObject(%obj.client))
			%obj.client.centerprint("You already have full ammo!", 2);
		return;
	}
	
	%obj.numArrows += %this.item.arrowAmmo;
	%diff = %obj.numArrows - $Pref::AmmoBow::MaxAmmo;
	%obj.numArrows = getMin(%obj.numArrows, $Pref::AmmoBow::MaxAmmo);

	for (%i = 0; %i < %diff; %i++)
	{
		%item = new Item (ArrowDrops)
		{
			dataBlock = AmmoBowArrowItem;
		};
		%item.setScale(%obj.getScale());
		MissionCleanup.add(%item);
		%item.setTransform(%obj.getMuzzlePoint(%slot) SPC rotFromTransform(%obj.getTransform()));
		%item.setVelocity(vectorAdd(vectorScale(%obj.getEyeVector(), 8), getRandom(-3, 3)  SPC getRandom(-3, 3) SPC 0));
		%item.minigame = getMinigameFromObject(%obj);
		%item.bl_id = %obj.client.getBLID();
		%item.setCollisionTimeout(%obj);
		%item.schedule($Item::popTime, schedulePop);
	}

	%obj.tool[%obj.currTool] = 0;
	%obj.weaponCount--;
	messageClient(%obj.client, 'MsgItemPickup', '', %obj.currTool, 0);
	%obj.client.centerprint("<just:right><color:ffffff>Arrows: \c3" @ %obj.numArrows @ "/" @ $Pref::AmmoBow::MaxAmmo @ " ", 3);
	%obj.unmountImage(%slot);
}