//Bow.cs
//bow and arrow weapon stuff

//////////
// item //
//////////
datablock ItemData(AmmoBowItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./bow.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Ammo Bow";
	iconName = "./icon_bow";
	doColorShift = true;
	colorShiftColor = "0.400 0.196 0 1.000";

	 // Dynamic properties defined by the scripts
	image = AmmoBowImage;
	canDrop = true;

	maxAmmo = 30;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(AmmoBowImage)
{
	// Basic Item properties
	shapeFile = "./bow.dts";
	emap = true;

	// Specify mount point & offset for 3rd person, and eye offset
	// for first person rendering.
	mountPoint = 0;
	offset = "0 0 0";
	eyeOffset = 0; //"0.7 1.2 -0.5";
	rotation = eulerToMatrix( "0 0 10" );

	// When firing from a point offset from the eye, muzzle correction
	// will adjust the muzzle vector to point to the eye LOS point.
	// Since this weapon doesn't actually fire from the muzzle point,
	// we need to turn this off.  
	correctMuzzleVector = true;

	// Add the WeaponImage namespace as a parent, WeaponImage namespace
	// provides some hooks into the inventory system.
	className = "WeaponImage";

	// Projectile && Ammo.
	item = AmmoBowItem;
	ammo = " ";
	projectile = arrowProjectile;
	projectileType = Projectile;

	//melee particles shoot from eye node for consistancy
	melee = false;
	//raise your arm up or not
	armReady = true;

	doColorShift = true;
	colorShiftColor = AmmoBowItem.colorShiftColor;//"0.400 0.196 0 1.000";
	maxAmmo = 30;

	//casing = " ";

	// Images have a state system which controls how the animations
	// are run, which sounds are played, script callbacks, etc. This
	// state system is downloaded to the client so that clients can
	// predict state changes and animate accordingly.  The following
	// system supports basic ready->fire->reload transitions as
	// well as a no-ammo->dryfire idle state.

	// Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.01;
	stateWaitForTimeout[0]           = 1;
	stateTransitionOnTimeout[0]       = "AmmoWait";
	stateSequence[0]                 = "Fire";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "AmmoCheck";
	stateTimeoutValue[2]            = 0.05;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateSequence[2]                = "Fire";
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]			= true;
	stateSound[2]					= bowFireSound;

	stateName[3]			= "Reload";
	stateSequence[3]                = "Reload";
	stateAllowImageChange[3]        = false;
	stateTimeoutValue[3]            = 0.85;
	stateWaitForTimeout[3]		= true;
	stateTransitionOnTimeout[3]     = "Check";

	stateName[4]			= "Check";
	stateTransitionOnTriggerUp[4]	= "StopFire";
	stateTransitionOnTriggerDown[4]	= "Fire";

	stateName[5]                    = "StopFire";
	stateTransitionOnTimeout[5]     = "Ready";
	stateTimeoutValue[5]            = 0.2;
	stateAllowImageChange[5]        = false;
	stateWaitForTimeout[5]		= true;
	stateScript[5]                  = "onStopFire";

	stateName[6]                  = "AmmoCheck2";
	stateTransitionOnAmmo[6]      = "Reload";
	stateTransitionOnNoAmmo[6]    = "AmmoWait";

	stateName[7]                  = "AmmoCheck";
	stateScript[7]                = "onAmmoCheck";
	stateTransitionOnTimeout[7]   = "AmmoCheck2";
	stateTimeoutValue[7]          = 0.2;

	stateName[8]                  = "AmmoWait";
	stateTimeoutValue[8]          = 0.1;
	stateTransitionOnTimeout[8]   = "AmmoCheck";
};

function AmmoBowImage::onUnmount(%this, %obj, %slot)
{
	if (isObject(%obj.client))
		%obj.client.centerprint();
}

function AmmoBowImage::onAmmoCheck(%this, %obj, %slot)
{
	%obj.numArrows = getMin(%obj.numArrows, $Pref::AmmoBow::MaxAmmo);
	if (%obj.numArrows > 0)
	{
		%obj.setImageAmmo(%slot, 1);
		%arrows = "\c3" @ %obj.numArrows;
	}
	else
	{
		%obj.setImageAmmo(%slot, 0);
		%arrows = "\c0" @ (%obj.numArrows = 0);
	}

	if (isObject(%obj.client))
		%obj.client.centerprint("<just:right><color:ffffff>Arrows: \c3" @ %obj.numArrows @ "/" @ $Pref::AmmoBow::MaxAmmo @ " ", -1);
}

function AmmoBowImage::onFire(%this, %obj, %slot)
{
	%obj.numArrows--;
	parent::onFire(%this, %obj, %slot);
}